# sample_project/main_asm

# Purchase Part

name | quantity | price | seller | desctiption
sample_project/base_plate | 1 | 155 yen | http://afdg/dfgaf.html | screw
sample_project/bar_plate | 2 | 155 yen | http://afdg/dfgaf.html | screw
screw_m3/pan_10 | 8 | 155 yen | http://afdg/dfgaf.html | screw
screw_m3/hollow_spacer_20 | 4 | 155 yen | http://afdg/dfgaf.html | screw

# Prepair Part

# Assembly Part

## sample_project/side_asm x2

### step 1

name | quantity
sample_project/bar_plate | 1

### step 2

name | quantity
screw_m3/pan_10 | 1
screw_m3/pan_10 | 1
screw_m3/hollow_spacer_20 | 1
screw_m3/hollow_spacer_20 | 1

## sample_project/main_asm x1

### step 1

name | quantity
sample_project/base_plate | 1

### step 2

name | quantity
sample_project/side_asm | 1
screw_m3/pan_10 | 1
screw_m3/pan_10 | 1

### step 3

name | quantity
sample_project/side_asm | 1
screw_m3/pan_10 | 1
screw_m3/pan_10 | 1

powered by roborecipe